@@ -1,3 +1,4 @@
+import itertools
 import os
 import re
 from collections import defaultdict
@@ -20,7 +21,7 @@ from snakeoil.strings import pluralism
 from .. import addons, results, sources
 from ..addons import UnstatedIuse
 from ..base import LogMap, LogReports
-from . import Check
+from . import Check, GentooRepoCheck
 from .visibility import FakeConfigurable
 
 
@@ -569,9 +570,9 @@ class LocalUseCheck(Check):
                 elif ratio >= 0.75:
                     yield ProbableGlobalUse(flag, pkg=pkg)
             elif '_' in flag:
-                for group in self.use_expand:
+                for group, flags in self.use_expand.items():
                     if flag.startswith(f'{group}_'):
-                        if flag not in self.use_expand[group]:
+                        if flag not in flags:
                             yield ProbableUseExpand(flag, group.upper(), pkg=pkg)
                         break
                 else:
@@ -586,6 +587,69 @@ class LocalUseCheck(Check):
             yield MissingLocalUseDesc(sorted(missing_desc), pkg=pkg)
 
 
+class UseFlagWithoutDeps(results.VersionResult, results.Warning):
+    """Special USE flag with little utility and without effect on dependencies.
+
+    Various USE flags, such as "ipv6", should be always turned on or off, and
+    their existence is questionable, in cases were it doesn't introduce new
+    dependencies. Other USE flags, such as "bash-completion", without any new
+    dependencies, are probable violators of small files QA policy [#]_.
+
+    In cases where this USE flag is appropriate, you can silence this warning
+    by adding a description to this USE flag in ``metadata.xml`` file and thus
+    making it a local USE flag instead of global one.
+
+    .. [#] https://projects.gentoo.org/qa/policy-guide/installed-files.html#pg0301
+    """
+
+    def __init__(self, flags, **kwargs):
+        super().__init__(**kwargs)
+        self.flags = tuple(flags)
+
+    @property
+    def desc(self):
+        s = pluralism(self.flags)
+        flags = ', '.join(self.flags)
+        return f'special small-files USE flag{s} without effect on dependencies: [ {flags} ]'
+
+
+class UseFlagsWithoutEffectsCheck(GentooRepoCheck):
+    """Check for USE flags without effects."""
+
+    known_results = frozenset({
+        UseFlagWithoutDeps,
+    })
+
+    warn_use_small_files = frozenset({
+        'ipv6', 'logrotate', 'unicode',
+        'bash-completion', 'fish-completion', 'zsh-completion', 'vim-syntax',
+        # TODO: enable those one day
+        # 'systemd',
+    })
+
+    def feed(self, pkg):
+        used_flags = set(pkg.local_use)
+        for attr in pkg.eapi.dep_keys:
+            deps = getattr(pkg, attr.lower())
+
+            use_values = set()
+            use_values.update(itertools.chain.from_iterable(
+                atom.use or ()
+                for atom in iflatten_instance(deps, atom_cls)
+            ))
+            use_values.update(itertools.chain.from_iterable(
+                atom.restriction.vals
+                for atom in iflatten_instance(deps, packages.Conditional)
+                if isinstance(atom, packages.Conditional) and atom.attr == 'use'
+            ))
+            for check_use in self.warn_use_small_files:
+                if any(check_use in use for use in use_values):
+                    used_flags.add(check_use)
+
+        flags = self.warn_use_small_files.intersection(pkg.iuse_stripped).difference(used_flags)
+        if flags:
+            yield UseFlagWithoutDeps(flags, pkg=pkg)
+
 class MissingSlotDep(results.VersionResult, results.Warning):
     """Missing slot value in dependencies.
 
@@ -740,6 +804,27 @@ class InvalidIdepend(results.MetadataError, results.VersionResult):
     attr = 'idepend'
 
 
+class MisplacedWeakBlocker(results.Warning, results.VersionResult):
+    """Weak blocker is within a misplaced dependency class.
+
+    Weak blockers control whether we ignore file collisions at the point of
+    merge, so being (exclusively) defined in DEPEND or BDEPEND is wrong.
+
+    Note that in cases where the weak blocker is also defined in RDEPEND, this
+    warning won't be triggered, to give leeway given this is a common ebuild
+    pattern.
+    """
+
+    def __init__(self, attr, atom, **kwargs):
+        super().__init__(**kwargs)
+        self.attr = attr.upper()
+        self.atom = str(atom)
+
+    @property
+    def desc(self):
+        return f'{self.attr}: misplaced weak blocker: {self.atom}'
+
+
 class DependencyCheck(Check):
     """Verify dependency attributes (e.g. RDEPEND)."""
 
@@ -747,7 +832,7 @@ class DependencyCheck(Check):
     known_results = frozenset([
         BadDependency, MissingPackageRevision, MissingUseDepDefault,
         UnstatedIuse, DeprecatedDep, InvalidDepend, InvalidRdepend,
-        InvalidPdepend, InvalidBdepend, InvalidIdepend,
+        InvalidPdepend, InvalidBdepend, InvalidIdepend, MisplacedWeakBlocker,
     ])
 
     def __init__(self, *args, use_addon):
@@ -778,6 +863,8 @@ class DependencyCheck(Check):
     def feed(self, pkg):
         deprecated = defaultdict(set)
 
+        weak_blocks = defaultdict(set)
+
         for attr in sorted(x.lower() for x in pkg.eapi.dep_keys):
             try:
                 deps = getattr(pkg, attr)
@@ -825,6 +912,15 @@ class DependencyCheck(Check):
                         elif atom.slot_operator == '=':
                             yield BadDependency(
                                 attr, atom, '= slot operator used in blocker', pkg=pkg)
+                        elif not atom.blocks_strongly:
+                            weak_blocks[attr].add(atom)
+
+        for attr in ('depend', 'bdepend'):
+            weak_blocks[attr].difference_update(weak_blocks['rdepend'])
+        weak_blocks['idepend'].difference_update(weak_blocks['rdepend'], weak_blocks['depend'])
+        for attr in ('depend', 'bdepend', 'idepend', 'pdepend'):
+            for atom in weak_blocks[attr]:
+                yield MisplacedWeakBlocker(attr, atom, pkg=pkg)
 
         for attr, atoms in deprecated.items():
             yield DeprecatedDep(attr.upper(), map(str, sorted(atoms)), pkg=pkg)
