@@ -274,12 +274,14 @@ class MetadataUrlCheck(_UrlCheck):
             'gentoo': 'https://gitweb.gentoo.org/{project}.git/',
             'github': 'https://github.com/{project}',
             'gitlab': 'https://gitlab.com/{project}',
+            'hackage': 'https://hackage.haskell.org/package/{project}',
             'launchpad': 'https://launchpad.net/{project}',
             'osdn': 'https://osdn.net/projects/{project}/',
             'pecl': 'https://pecl.php.net/package/{project}',
             'pypi': 'https://pypi.org/project/{project}/',
             'rubygems': 'https://rubygems.org/gems/{project}',
             'sourceforge': 'https://sourceforge.net/projects/{project}/',
+            'sourcehut': 'https://sr.ht/{project}/',
             'vim': 'https://vim.org/scripts/script.php?script_id={project}',
             # these platforms return 200 for errors, so no point in trying
             # 'google-code': 'https://code.google.com/archive/p/{project}/',
